==> viha-5.15.tar.gz: viha-5.15/paivystys-ok.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

# sanity check functions for database additions, modifications and
# deletions.
# general format is ret = table_what_ok(&$msg,$id, ...)
# msg is error/warning message
# id is the main id of the record in question, new record => id = ''
# return codes:
#  0 (all ok, msg undefined)
#  1 (warnings in msg)
#  2 (fatal, reason in msg)

# paivystys tarkastusfunktiot

function paivystys_ok(&$msg,$id,$alue_id,$nimi,$oletus_verkko_id,
		      $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
		      $strict = true) {
  global $table, $prefix;
  
  $msg = '';
  
  if ($id != "") {
    $id_sql = "AND id != $id";
    $modify = 1;
    $tail = " Ei voi muuttaa.";
  } else {
    $modify = 0;
    $tail = " Ei voi list.";
  }

  # tarpeelliset kentt
  if ($nimi == '') {
    $msg = 'Operaation nimi on pakollinen tieto.';
    $msg .= $tail;
    return 2;
  }

  # alue oltava olemassa
  if (tab_col_id("alue","id",$alue_id) == '') {
    $msg = "Aluetta $alue_id ei lydy.";
    $msg .= $tail;
    return 2;
  }
  
  # verkko oltava olemassa
  if (tab_col_id("verkko","",$oletus_verkko_id) == '') {
    $msg = "Verkkoa $oletus_verkko_id ei lydy.";
    $msg .= $tail;
    return 2;
  }

  # johtoryhmn oltava joko 1 (ei asetettu) tai kuuluttava thn operaatioon
  if ($modify) {
    # makes sense only if we already have an id
    if (tab_col_id("ryhma","kutsu",$johto_ryhma_id) == '') {
      $msg = "Ryhm $johto_ryhma_id ei lydy.";
      $msg .= $tail;
      return 2;
    }
    $johto_ryhma_a_id = tab_col_id("ryhma","alue_id",$johto_ryhma_id);
    $johto_ryhma_p_id = tab_col_id("ryhma","paivystys_id",$johto_ryhma_id);
    if (($johto_ryhma_id != 1)
	&& ($johto_ryhma_p_id != $id)) {
      $msg = "Ryhm $johto_ryhma_id ei sovi johtoryhmksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } else {
    # no id, be very strict
    if ($johto_ryhma_id != 1) {
      $msg = "Ryhm $johto_ryhma_id ei sovi johtoryhmksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } # modify
  # viestiaseman oltava joko 1 (ei asetettu) tai kuuluttava thn operaatioon
  if ($modify) {
    # makes sense only if we already have an id
    if (tab_col_id("ryhma","kutsu",$viesti_ryhma_id) == '') {
      $msg = "Ryhm $viesti_ryhma_id ei lydy.";
      $msg .= $tail;
      return 2;
    }
    $viesti_ryhma_a_id = tab_col_id("ryhma","alue_id",$viesti_ryhma_id);
    $viesti_ryhma_p_id = tab_col_id("ryhma","paivystys_id",$viesti_ryhma_id);
    if (($viesti_ryhma_id != 1)
	&& ($viesti_ryhma_p_id != $id)) {
      $msg = "Ryhm $viesti_ryhma_id ei sovi viestiasemaksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } else {
    # no id, be very strict
    if ($viesti_ryhma_id != 1) {
      $msg = "Ryhm $viesti_ryhma_id ei sovi viestiasemaksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } # modify
  
  # tukiasemat
  if ($modify) {
    # makes sense only if we already have an id
    foreach ($tuki_ids as $ryhma_id) {
      $ryhma_paivystys_id = tab_col_id("ryhma","paivystys_id",$ryhma_id);
      if ($ryhma_paivystys_id != $id) {
	$msg = "Ryhm $ryhma_id ei sovi tukiasemaksi thn operaatioon.";
	$msg .= $tail;
	return 2;
      }
    }
  } else {
    # XXX no id, no check
  } # modify
  
  # duplikaatit
  $dup =
    ota_yksi("SELECT id
              FROM $table
              WHERE nimi = '$nimi'
              $id_sql");
  if ($dup != '') {
    $msg = "Tllainen operaatio on jo olemassa (id=$dup)";
    $msg .= $tail;
    return 2;
  }

  if ($strict) {
    # tiukka kyttoikeustarkastus: oltava aluevastaava p.o. alueella
    # tai pkyttj.
    if (alue_oikeus($alue_id) == 2) {
      $msg = "Oikeutesi eivt riit tmn tehtvn suorittamiseen.";
      $msg .= $tail;
      return 2;
    }
  } else {
    # lysempi, hyvksytn muutokset nykyiseen operaatioon
    if (! $modify || ($alue_id != s('alue'))
	|| ($id != s('paivystys'))) {
      $msg = "Oikeutesi eivt riit tmn tehtvn suorittamiseen.";
      $msg .= $tail;
      return 2;
    }
  }

  return 0;
}

function paivystys_add_ok(&$msg,$alue_id,$nimi,$oletus_verkko_id,
			  $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
			  $strict = true) {
  return paivystys_ok($msg,'',$alue_id,$nimi,$oletus_verkko_id,
		      $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
		      $strict);
}

function paivystys_save_ok(&$msg,$id,$alue_id,$nimi,$oletus_verkko_id,
			   $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
			   $strict = true) {
  return paivystys_ok($msg,$id,$alue_id,$nimi,$oletus_verkko_id,
		      $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
		      $strict);
}

function paivystys_remove_ok(&$msg, $id, $log = true) {
  $msg = '';
  $ret = 0;

  # operaatioita 1 ja 2 ei voi poistaa
  if ($id == 1 || $id == 2) {
    $msg = "Operaatioita numero 1 ja 2 ei voi poistaa.";
    return 2;
  }

  $p_ret = paivystys_id_ok($msg,$id);
  if ($p_ret == 2) {
    return 2;
  }

  # kyttoikeustarkastus: oltava aluevastaava p.o. alueella tai pkyttj.
  $paivystys_alue_id = tab_col_id("paivystys","alue_id",$id);
  if (alue_oikeus($paivystys_alue_id) == 2) {
    $msg = "Oikeutesi eivt riit tmn tehtvn suorittamiseen.";
    $msg .= $tail;
    return 2;
  }

  # jos operaatioon on viittauksia, sit ei voi poistaa
  $ref =
    ota_yksi("SELECT COUNT(*)
              FROM kayttajat_paivystys
              WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri psyoikeustiedossa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM paikka WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri sijainnissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM ryhma_tila WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri ryhmn tilakoodissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM ryhma WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri ryhmn tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM jarjesto WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri jrjestss.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM hlo_tila WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri henkiln tilakoodissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM hlo WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri henkiln tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM kadonnut WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref kadonneen tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM loytynyt WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref lytyneen tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM loki WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on $ref viittausta teknisess lokissa.";
    $ret = 2;
  }
  $ref =
    ota_yksi("SELECT COUNT(*) FROM taktinen_loki WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on $ref viittausta tapahtumapivkirjassa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM laite WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= "Thn operaatioon on viittauksia $ref viestivlineess.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM tavara WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= "Thn operaatioon on viittauksia $ref tavarassa.";
    $ret = 2;
  }

  if ($ret == 2) {
    $msg .= " Sit ei voi poistaa ennen kuin viittaukset on siivottu.";
  }
  return $ret;
}

# aux functions for handling lists related to operations.

# tehdn valinta kaikista mahdollisista tukiasemista tiettyyn operaatioon.

function select_tuki_ids($paivystys_id) {

  # meaningless if we do not have id
  if ($paivystys_id == 0)
    return;
  
  $koko = ota_yksi("SELECT COUNT(*)
                    FROM ryhma
                    WHERE paivystys_id = $paivystys_id");
  if ($koko > 5)
    $koko = 5;
  echo "<select multiple size=\"$koko\" name=\"tuki_ids[]\">\n";

  $sql =
    "SELECT id, kutsu
     FROM ryhma
     WHERE paivystys_id = $paivystys_id
     ORDER BY pri";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($data = mysql_fetch_row($result)) {
      $option_value = $data[0];
      $option_label = $data[1];
      echo "<option value=\"$option_value\"";
      if (ota_yksi("SELECT COUNT(*)
                    FROM paivystys_tuki
                    WHERE paivystys_id = $paivystys_id
                          AND ryhma_id = $option_value"))
	echo " selected";
      echo ">$option_label\n";
    }
  }
  echo "</select>\n";
}

# nytetn taulukossa olevat ryhmat

function list_tuki_ids($tuki_ids) {
  foreach ($tuki_ids as $id) {
    echo " " . tab_col_id("ryhma","kutsu",$id);
  }
  echo "\n";
}

# tehdn tuki_ids lista tiettyyn operaatioon.
 
function fetch_tuki_ids($paivystys_id) {
  $ret = array();
  $sql =
    "SELECT ryhma_id
     FROM paivystys_tuki
     WHERE paivystys_id = $paivystys_id";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($d = mysql_fetch_row($result)) {
      $ret[] = $d[0];
    }
  }
  return $ret;
}

# asetetaan operaation tuki_ids lista kantaan.
 
function set_tuki_ids($now,$id,$tuki_ids) {
  $now = date('Y-m-d H:i:s');
  $sql = "DELETE FROM paivystys_tuki WHERE paivystys_id = $id;";
  my_mysql_query($sql,true,true);
  foreach ($tuki_ids as $ryhma_id) {
    $sql =
      "INSERT INTO paivystys_tuki
       SET ryhma_id = $ryhma_id,
           paivystys_id = $id,
           ts = '$now'";
    my_mysql_query($sql,true,true);
  }
}

?>

<!-- RCS $Id: paivystys-ok.php,v 1.27 2009/04/20 11:10:10 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/paivystys-ok.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

# sanity check functions for database additions, modifications and
# deletions.
# general format is ret = table_what_ok(&$msg,$id, ...)
# msg is error/warning message
# id is the main id of the record in question, new record => id = ''
# return codes:
#  0 (all ok, msg undefined)
#  1 (warnings in msg)
#  2 (fatal, reason in msg)

# paivystys tarkastusfunktiot

function paivystys_ok(&$msg,$id,$alue_id,$nimi,$oletus_verkko_id,
		      $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,$alkoi,
		      $strict = true) {
  global $table, $prefix;
  
  $msg = '';
  
  if ($id != "") {
    $id_sql = "AND id != $id";
    $modify = 1;
    $tail = " Ei voi muuttaa.";
  } else {
    $modify = 0;
    $tail = " Ei voi list.";
  }

  # tarpeelliset kentt
  if ($nimi == '') {
    $msg = 'Operaation nimi on pakollinen tieto.';
    $msg .= $tail;
    return 2;
  }

  # alue oltava olemassa
  if (tab_col_id("alue","id",$alue_id) == '') {
    $msg = "Aluetta $alue_id ei lydy.";
    $msg .= $tail;
    return 2;
  }
  
  # verkko oltava olemassa
  if (tab_col_id("verkko","",$oletus_verkko_id) == '') {
    $msg = "Verkkoa $oletus_verkko_id ei lydy.";
    $msg .= $tail;
    return 2;
  }

  # johtoryhmn oltava joko 1 (ei asetettu) tai kuuluttava thn operaatioon
  if ($modify) {
    # makes sense only if we already have an id
    if (tab_col_id("ryhma","kutsu",$johto_ryhma_id) == '') {
      $msg = "Ryhm $johto_ryhma_id ei lydy.";
      $msg .= $tail;
      return 2;
    }
    $johto_ryhma_a_id = tab_col_id("ryhma","alue_id",$johto_ryhma_id);
    $johto_ryhma_p_id = tab_col_id("ryhma","paivystys_id",$johto_ryhma_id);
    if (($johto_ryhma_id != 1)
	&& ($johto_ryhma_p_id != $id)) {
      $msg = "Ryhm $johto_ryhma_id ei sovi johtoryhmksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } else {
    # no id, be very strict
    if ($johto_ryhma_id != 1) {
      $msg = "Ryhm $johto_ryhma_id ei sovi johtoryhmksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } # modify
  # viestiaseman oltava joko 1 (ei asetettu) tai kuuluttava thn operaatioon
  if ($modify) {
    # makes sense only if we already have an id
    if (tab_col_id("ryhma","kutsu",$viesti_ryhma_id) == '') {
      $msg = "Ryhm $viesti_ryhma_id ei lydy.";
      $msg .= $tail;
      return 2;
    }
    $viesti_ryhma_a_id = tab_col_id("ryhma","alue_id",$viesti_ryhma_id);
    $viesti_ryhma_p_id = tab_col_id("ryhma","paivystys_id",$viesti_ryhma_id);
    if (($viesti_ryhma_id != 1)
	&& ($viesti_ryhma_p_id != $id)) {
      $msg = "Ryhm $viesti_ryhma_id ei sovi viestiasemaksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } else {
    # no id, be very strict
    if ($viesti_ryhma_id != 1) {
      $msg = "Ryhm $viesti_ryhma_id ei sovi viestiasemaksi thn operaatioon.";
      $msg .= $tail;
      return 2;
    }
  } # modify
  
  # tukiasemat
  if ($modify) {
    # makes sense only if we already have an id
    foreach ($tuki_ids as $ryhma_id) {
      $ryhma_paivystys_id = tab_col_id("ryhma","paivystys_id",$ryhma_id);
      if ($ryhma_paivystys_id != $id) {
	$msg = "Ryhm $ryhma_id ei sovi tukiasemaksi thn operaatioon.";
	$msg .= $tail;
	return 2;
      }
    }
  } else {
    # XXX no id, no check
  } # modify

  if (timestamp_ok($alkoi) != 0) {
    $msg = "Aikaleima $alkoi ei kelpaa";
    $msg .= $tail;
    return 2;
  }
  
  # duplikaatit
  $dup =
    ota_yksi("SELECT id
              FROM $table
              WHERE nimi = '$nimi' AND alkoi = '$alkoi'
              $id_sql");
  if ($dup != '') {
    $msg = "Tllainen operaatio on jo olemassa (id=$dup)";
    $msg .= $tail;
    return 2;
  }

  if ($strict) {
    # tiukka kyttoikeustarkastus: oltava aluevastaava p.o. alueella
    # tai pkyttj.
    if (alue_oikeus($alue_id) == 2) {
      $msg = "Oikeutesi eivt riit tmn tehtvn suorittamiseen.";
      $msg .= $tail;
      return 2;
    }
  } else {
    # lysempi, hyvksytn muutokset nykyiseen operaatioon
    if (! $modify || ($alue_id != s('alue'))
	|| ($id != s('paivystys'))) {
      $msg = "Oikeutesi eivt riit tmn tehtvn suorittamiseen.";
      $msg .= $tail;
      return 2;
    }
  }

  return 0;
}

function paivystys_add_ok(&$msg,$alue_id,$nimi,$oletus_verkko_id,
			  $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
			  $strict = true) {
  return paivystys_ok($msg,'',$alue_id,$nimi,$oletus_verkko_id,
		      $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
		      $strict);
}

function paivystys_save_ok(&$msg,$id,$alue_id,$nimi,$oletus_verkko_id,
			   $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
			   $strict = true) {
  return paivystys_ok($msg,$id,$alue_id,$nimi,$oletus_verkko_id,
		      $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
		      $strict);
}

function paivystys_remove_ok(&$msg, $id, $log = true) {
  $msg = '';
  $ret = 0;

  # operaatioita 1 ja 2 ei voi poistaa
  if ($id == 1 || $id == 2) {
    $msg = "Operaatioita numero 1 ja 2 ei voi poistaa.";
    return 2;
  }

  $p_ret = paivystys_id_ok($msg,$id);
  if ($p_ret == 2) {
    return 2;
  }

  # kyttoikeustarkastus: oltava aluevastaava p.o. alueella tai pkyttj.
  $paivystys_alue_id = tab_col_id("paivystys","alue_id",$id);
  if (alue_oikeus($paivystys_alue_id) == 2) {
    $msg = "Oikeutesi eivt riit tmn tehtvn suorittamiseen.";
    $msg .= $tail;
    return 2;
  }

  # jos operaatioon on viittauksia, sit ei voi poistaa
  $ref =
    ota_yksi("SELECT COUNT(*)
              FROM kayttajat_paivystys
              WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri psyoikeustiedossa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM paikka WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri sijainnissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM ryhma_tila WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri ryhmn tilakoodissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM ryhma WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri ryhmn tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM jarjesto WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri jrjestss.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM hlo_tila WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri henkiln tilakoodissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM hlo WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref eri henkiln tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM kadonnut WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref kadonneen tiedoissa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM loytynyt WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on viittauksia $ref lytyneen tiedoissa.";
    $ret = 2;
  }
  $ref =
    ota_yksi("SELECT COUNT(*) FROM taktinen_loki WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= " Thn operaatioon on $ref viittausta tapahtumapivkirjassa.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM laite WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= "Thn operaatioon on viittauksia $ref viestivlineess.";
    $ret = 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM tavara WHERE paivystys_id = $id");
  if ($ref != 0) {
    $msg .= "Thn operaatioon on viittauksia $ref tavarassa.";
    $ret = 2;
  }

  if ($ret == 2) {
    $msg .= " Sit ei voi poistaa ennen kuin viittaukset on siivottu.";
  }
  return $ret;
}

# aux functions for handling lists related to operations.

# tehdn valinta kaikista mahdollisista tukiasemista tiettyyn operaatioon.

function select_tuki_ids($paivystys_id) {

  # meaningless if we do not have id
  if ($paivystys_id == 0)
    return;
  
  $koko = ota_yksi("SELECT COUNT(*)
                    FROM ryhma
                    WHERE paivystys_id = $paivystys_id");
  if ($koko > 5)
    $koko = 5;
  echo "<select multiple size=\"$koko\" name=\"tuki_ids[]\">\n";

  $sql =
    "SELECT id, kutsu
     FROM ryhma
     WHERE paivystys_id = $paivystys_id
     ORDER BY pri";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($data = mysql_fetch_row($result)) {
      $option_value = $data[0];
      $option_label = $data[1];
      echo "<option value=\"$option_value\"";
      if (ota_yksi("SELECT COUNT(*)
                    FROM paivystys_tuki
                    WHERE paivystys_id = $paivystys_id
                          AND ryhma_id = $option_value"))
	echo " selected";
      echo ">$option_label\n";
    }
  }
  echo "</select>\n";
}

# nytetn taulukossa olevat ryhmat

function list_tuki_ids($tuki_ids) {
  foreach ($tuki_ids as $id) {
    echo " " . tab_col_id("ryhma","kutsu",$id);
  }
  echo "\n";
}

# tehdn tuki_ids lista tiettyyn operaatioon.
 
function fetch_tuki_ids($paivystys_id) {
  $ret = array();
  $sql =
    "SELECT ryhma_id
     FROM paivystys_tuki
     WHERE paivystys_id = $paivystys_id";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($d = mysql_fetch_row($result)) {
      $ret[] = $d[0];
    }
  }
  return $ret;
}

# asetetaan operaation tuki_ids lista kantaan.
 
function set_tuki_ids($now,$id,$tuki_ids) {
  $now = date('Y-m-d H:i:s');
  $sql = "DELETE FROM paivystys_tuki WHERE paivystys_id = $id;";
  my_mysql_query($sql,true,true);
  foreach ($tuki_ids as $ryhma_id) {
    $sql =
      "INSERT INTO paivystys_tuki
       SET ryhma_id = $ryhma_id,
           paivystys_id = $id,
           ts = '$now'";
    my_mysql_query($sql,true,true);
  }
}

?>

<!-- RCS $Id: paivystys-ok.php,v 1.29 2009/07/06 07:52:34 riku Exp $ -->
